@@ -7,7 +7,7 @@ RDF::Trine::Node::Blank - RDF Node class for blank nodes
 
 =head1 VERSION
 
-This document describes RDF::Trine::Node::Blank version 0.132_03
+This document describes RDF::Trine::Node::Blank version 0.133_01
 
 =cut
 
@@ -26,7 +26,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.132_03';
+	$VERSION	= '0.133_01';
 }
 
 ######################################################################
@@ -79,6 +79,17 @@ sub blank_identifier {
 	return $self->[1];
 }
 
+=item C<< value >>
+
+Returns the blank identifier.
+
+=cut
+
+sub value {
+	my $self	= shift;
+	return $self->blank_identifier;
+}
+
 =item C<< sse >>
 
 Returns the SSE string for this blank node.
